<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="话术" prop="questionID">
        <el-input v-model="queryParams.questionID" placeholder="请输入${comment}" clearable
          @keyup.enter.native="handleQuery" />
      </el-form-item>
      <el-form-item label="指标名称" prop="categoryName">
        <el-input v-model="queryParams.categoryName" placeholder="请输入${comment}" clearable
          @keyup.enter.native="handleQuery" />
      </el-form-item>
      <el-form-item label="指标值" prop="targetValue">
        <el-input v-model="queryParams.targetValue" placeholder="请输入${comment}" clearable
          @keyup.enter.native="handleQuery" />
      </el-form-item>
      <el-form-item label="适用院区" prop="orgid">
        <el-input v-model="queryParams.orgid" placeholder="请输入 机构ID " clearable @keyup.enter.native="handleQuery" />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button type="primary" plain icon="el-icon-plus" size="mini" @click="handleAdd"
          v-hasPermi="['smartor:ivrscripttarget:add']">新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="success" plain icon="el-icon-edit" size="mini" :disabled="single" @click="handleUpdate"
          v-hasPermi="['smartor:ivrscripttarget:edit']">修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="danger" plain icon="el-icon-delete" size="mini" :disabled="multiple" @click="handleDelete"
          v-hasPermi="['smartor:ivrscripttarget:remove']">删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="warning" plain icon="el-icon-download" size="mini" @click="handleExport"
          v-hasPermi="['smartor:ivrscripttarget:export']">导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="ivrscripttargetList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="话术" align="center" prop="questionID" />
      <el-table-column label="指标类型" align="center" prop="targetType" />
      <el-table-column label="指标名称" align="center" prop="categoryName" />
      <el-table-column label="指标值" align="center" prop="targetValue" />
      <el-table-column label="序号" align="center" prop="sort" />
      <el-table-column label="版本号" align="center" prop="version" />
      <el-table-column label="启用标识" align="center" prop="isEnable" />
      <el-table-column label="删除标识" align="center" prop="isDel" />
      <el-table-column label="${comment}" align="center" prop="tipsJson" />
      <el-table-column label="适用院区" align="center" prop="orgid" />
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button size="mini" type="text" icon="el-icon-edit" @click="handleUpdate(scope.row)"
            v-hasPermi="['smartor:ivrscripttarget:edit']">修改</el-button>
          <el-button size="mini" type="text" icon="el-icon-delete" @click="handleDelete(scope.row)"
            v-hasPermi="['smartor:ivrscripttarget:remove']">删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination v-show="total > 0" :total="total" :page.sync="queryParams.pageNum" :limit.sync="queryParams.pageSize"
      @pagination="getList" />

    <!-- 添加或修改话术库话术指标对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="1000px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="100px">
        <el-row>
          <el-col :span="24"><el-form-item label="话术" prop="questionID">
              <el-input v-model="form.questionID" placeholder="请输入${comment}" />
            </el-form-item></el-col>
        </el-row> <el-row>
          <el-col :span="12"><el-form-item label="指标名称" prop="categoryName">
              <el-input v-model="form.categoryName" placeholder="请输入${comment}" />
            </el-form-item></el-col>
          <el-col :span="12"><el-form-item label="指标值" prop="targetValue">
              <el-input v-model="form.targetValue" placeholder="请输入${comment}" />
            </el-form-item></el-col>
        </el-row><el-row>
          <el-col :span="12"><el-form-item label="序号" prop="sort">
              <el-input v-model="form.sort" placeholder="请输入${comment}" />
            </el-form-item></el-col>
          <el-col :span="12"><el-form-item label="版本号" prop="version">
              <el-input v-model="form.version" placeholder="请输入${comment}" />
            </el-form-item></el-col>
        </el-row> <el-row>
          <el-col :span="12"><el-form-item label="启用标识" prop="isEnable">
              <el-input v-model="form.isEnable" placeholder="请输入${comment}" />
            </el-form-item></el-col>
          <el-col :span="12"><el-form-item label="删除标记" prop="delFlag">
              <el-input v-model="form.delFlag" placeholder="请输入 删除标记 " />
            </el-form-item></el-col>
        </el-row> <el-row>
          <el-col :span="24"><el-form-item label="提示信息" prop="tipsJson">
              <el-input v-model="form.tipsJson" type="textarea" placeholder="请输入内容" />
            </el-form-item></el-col>
        </el-row> <el-row>
          <el-col :span="24"><el-form-item label="适用院区" prop="orgid">
              <el-input v-model="form.orgid" placeholder="请输入 机构ID " />
            </el-form-item></el-col>
        </el-row><el-row>
          <el-col :span="24"><el-form-item label="匹配规则" prop="basicRegex">
              <el-input v-model="form.basicRegex" type="textarea" placeholder="请输入内容" />
            </el-form-item></el-col>
        </el-row> 
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listIvrscripttarget, getIvrscripttarget, delIvrscripttarget, addIvrscripttarget, updateIvrscripttarget } from "@/api/smartor/ivrscripttarget";

export default {
  name: "Ivrscripttarget",
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 话术库话术指标表格数据
      ivrscripttargetList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        questionID: null,
        targetID: null,
        targetType: null,
        categoryName: null,
        targetValue: null,
        basicRegex: null,
        selfRegex: null,
        regexUsedType: null,
        sort: null,
        version: null,
        isEnable: null,
        isDel: null,
        tipsJson: null,
        isupload: null,
        uploadTime: null,
        orgid: null
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        questionID: [
          { required: true, message: "$comment不能为空", trigger: "blur" }
        ],
        sort: [
          { required: true, message: "$comment不能为空", trigger: "blur" }
        ],
        version: [
          { required: true, message: "$comment不能为空", trigger: "blur" }
        ],
        isEnable: [
          { required: true, message: "$comment不能为空", trigger: "blur" }
        ],
        isDel: [
          { required: true, message: "$comment不能为空", trigger: "blur" }
        ],
        delFlag: [
          { required: true, message: " 删除标记 不能为空", trigger: "blur" }
        ],
        isupload: [
          { required: true, message: " 上传标记 不能为空", trigger: "blur" }
        ],
      }
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询话术库话术指标列表 */
    getList() {
      this.loading = true;
      listIvrscripttarget(this.queryParams).then(response => {
        this.ivrscripttargetList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        questionTargetID: null,
        questionID: null,
        targetID: null,
        targetType: null,
        categoryName: null,
        targetValue: null,
        basicRegex: null,
        selfRegex: null,
        regexUsedType: null,
        sort: null,
        version: null,
        isEnable: null,
        isDel: null,
        tipsJson: null,
        delFlag: null,
        updateBy: null,
        updateTime: null,
        createBy: null,
        createTime: null,
        isupload: null,
        uploadTime: null,
        orgid: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.questionTargetID)
      this.single = selection.length !== 1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加话术库话术指标";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const questionTargetID = row.questionTargetID || this.ids
      getIvrscripttarget(questionTargetID).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改话术库话术指标";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.questionTargetID != null) {
            updateIvrscripttarget(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addIvrscripttarget(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const questionTargetIDs = row.questionTargetID || this.ids;
      this.$modal.confirm('是否确认删除话术库话术指标编号为"' + questionTargetIDs + '"的数据项？').then(function () {
        return delIvrscripttarget(questionTargetIDs);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => { });
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('smartor/ivrscripttarget/export', {
        ...this.queryParams
      }, `ivrscripttarget_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
